/////////////////////////////////////////////////////////////////////////////
// Name:        InterfaceImageDouble.h
// Purpose:     InterfaceImageDouble class
// Author:      Alain Bouju
// Modified by:
// Created:     07/02/00
// RCS-ID:      
// Copyright:   
// Licence:   
//////////////////////////////////////////////////////////////////////////////

/* Definition de la classe ImageBin */
#ifndef INTERFACEIMAGEDOUBLE_H__
#define INTERFACEIMAGEDOUBLE_H__

#include "define.h"
#include "Interface.h"

#ifdef __GNUG__
#pragma interface
#endif

#include "wx/wx.h"

#include "ImageDouble.h"
#include "MasqueDouble.h"

class MyFrame;

class wxFrame;

class ImageDouble;

class InterfaceImageDouble{
public :
	wxMenu *g_wMenuImageDouble;
	InterfaceImageDouble ();
	~InterfaceImageDouble (void);
	void InitInterfaceImageDouble ( void );
	void OnImageDouble(wxCommandEvent& event);
	void OnInverserDouble();
	void OnDiviserDouble();
	void OnImageDoubleAfficherMinMax();
	wxBitmap * VisualiserDouble (ImageDouble *l_pImageDouble);
	int AjouterImageDouble(wxString l_wNomImage, ImageDouble *l_pImageDouble);
	ImageDouble * ChercherImageDouble(wxString l_wNomImage);
};

#endif
